=============
API Reference
=============


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   fdi/modules
   fdi/fdi.dataset
   fdi/fdi.pal
   fdi/fdi.pns
   fdi/fdi.utils

Diagrams
========

packages_dataset.png

.. image:: ../_static/packages_dataset.png

classes_dataset.png

.. image:: ../_static/classes_dataset.png

packages_pal.png

.. image:: ../_static/packages_pal.png

classes_pal.png
	   
.. image:: ../_static/classes_pal.png

packages_pns.png
	   
.. image:: ../_static/packages_pns.png

classes_pns.png
	   
.. image:: ../_static/classes_pns.png


packages_all.png
	   
.. image:: ../_static/packages_all.png

classes_all.png
	   
.. image:: ../_static/classes_all.png

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

